@@ -41,9 +41,11 @@ class MythbuntuBaRePlugin(MCCPlugin):
     #
     #Load GUI & Calculate Changes
     #
+    
     CONFIGFILE = "/var/lib/mythtv/bare-client/mythbuntu-bare-client.conf"
 
-    USER=os.getenv("HOME")
+    #USER=os.getenv("HOME")  ## This doesn't work when passed to root changes
+    USER=os.path.expanduser('~')
 
     BACKUPFILES = [
     "/etc/mythtv/config.xml",
@@ -132,26 +134,26 @@ class MythbuntuBaRePlugin(MCCPlugin):
         self.on_backup_dir_button_toggled(None)
 #        self.on_backup_schedule_toggled(None)
         if self.changes['backup_schedule'] == "disabled":
-          self.scheduled_label.set_text("Disabled")
-          self.schedule_disabled_button.set_active(True)
+            self.scheduled_label.set_text("Disabled")
+            self.schedule_disabled_button.set_active(True)
         elif self.changes['backup_schedule'] == "daily":
-          self.schedule_daily_button.set_active(True)
+           self.schedule_daily_button.set_active(True)
         elif self.changes['backup_schedule'] == "weekly":
-          self.schedule_weekly_button.set_active(True)
-          wday = int(self.changes['backup_schedule_weekday'])
-          self.weekly_combobox.set_active(wday)
-          self.hbox_schedule_weekly.show()
+            self.schedule_weekly_button.set_active(True)
+            wday = int(self.changes['backup_schedule_weekday'])
+            self.weekly_combobox.set_active(wday)
+            self.hbox_schedule_weekly.show()
         elif self.changes['backup_schedule'] == "monthly":
-          self.schedule_monthly_button.set_active(True)
-          md = int(self.changes['backup_schedule_day'])
-          mday = md-1
-          self.monthly_combobox.set_active(mday)
-          self.hbox_schedule_monthly.show()
+            self.schedule_monthly_button.set_active(True)
+            md = int(self.changes['backup_schedule_day'])
+            mday = md-1
+            self.monthly_combobox.set_active(mday)
+            self.hbox_schedule_monthly.show()
         if not self.changes['backup_schedule'] == "disabled":
-          shour = self.changes['backup_schedule_hour']
-          self.schedule_hour_combobox.set_active(int(shour))
-          smin = int(self.changes['backup_schedule_minute'])/5
-          self.schedule_minute_combobox.set_active(int(smin))
+            shour = self.changes['backup_schedule_hour']
+            self.schedule_hour_combobox.set_active(int(shour))
+            smin = int(self.changes['backup_schedule_minute'])/5
+            self.schedule_minute_combobox.set_active(int(smin))
         self.restore_label_isfile.hide()
         self.managed_label_isfile.hide()
         ## Filter only tar.gz files for restore
@@ -167,9 +169,10 @@ class MythbuntuBaRePlugin(MCCPlugin):
         self.managedfilechooser.unselect_all()
         self.backup_location.unselect_all()
         ## Disable non-implemented items
-        self.backup_u1_button.hide()
         self.backup_dropbox_button.hide()
-        self.backup_dir_button.hide() ## Only disabled since no other locations are available
+        self.backup_u1_button.hide()
+        self.radio_convert.hide()
+        self.managed_label.hide()
 
     def compareState(self):
         """Determines what items have been modified on this plugin"""
@@ -179,23 +182,23 @@ class MythbuntuBaRePlugin(MCCPlugin):
                 self.BACKUP_LOCATION=self.backup_location.get_filename()
             self.BACKUP_DB = self.db_backup_checkbutton.get_active()
             if self.backup_now.get_active():
-                self._markReconfigureUser('Backup Now',self.BACKUP_LOCATION)
+                self._markReconfigureUser('BackupNow',self.BACKUP_LOCATION)
             elif self.backup_schedule.get_active():
                 #TODO
                 if self.schedule_disabled_button.get_active():
-                  self._markReconfigureRoot('Backup Schedule', False)
+                    self._markReconfigureRoot('BackupSchedule', False)
                 else:
-                  self._markReconfigureRoot('Backup Schedule', True)
-                  self._markReconfigureRoot('Backup Hour', self.schedule_hour_combobox.get_active_text())
-                  self._markReconfigureRoot('Backup Minute', self.schedule_minute_combobox.get_active_text())
-                  self._markReconfigureRoot('Backup Location', self.BACKUP_LOCATION)
-                  self._markReconfigureRoot('Backup Database', self.db_backup_checkbutton.get_active())
-                  if self.schedule_daily_button.get_active():
-                    self._markReconfigureRoot('Backup Daily', True)
-                  elif self.schedule_weekly_button.get_active():
-                    self._markReconfigureRoot('Backup Weekly', self.weekly_combobox.get_active())
-                  elif self.schedule_monthly_button.get_active():
-                    self._markReconfigureRoot('Backup Monthly', self.monthly_combobox.get_active_text())
+                    self._markReconfigureRoot('BackupSchedule', True)
+                    self._markReconfigureRoot('BackupHour', self.schedule_hour_combobox.get_active_text())
+                    self._markReconfigureRoot('BackupMinute', self.schedule_minute_combobox.get_active_text())
+                    self._markReconfigureRoot('BackupLocation', self.BACKUP_LOCATION)
+                    self._markReconfigureRoot('BackupDatabase', self.db_backup_checkbutton.get_active())
+                    if self.schedule_daily_button.get_active():
+                       self._markReconfigureRoot('BackupDaily', True)
+                    elif self.schedule_weekly_button.get_active():
+                       self._markReconfigureRoot('BackupWeekly', self.weekly_combobox.get_active())
+                    elif self.schedule_monthly_button.get_active():
+                        self._markReconfigureRoot('BackupMonthly', self.monthly_combobox.get_active_text())
         if self.radio_restore.get_active():
             self._markReconfigureRoot('restore',self.restore_file.get_filename())
         if self.restore_db.get_active():
@@ -227,37 +230,37 @@ class MythbuntuBaRePlugin(MCCPlugin):
 
     def on_managedfilechooser_selection_changed(self,widget,data=None):
         if self.managedfilechooser.get_filename():
-          newconfigfilename=self.managedfilechooser.get_filename()
-          newconfig = ConfigParser.ConfigParser()
-          newconfig.read(newconfigfilename)
-          self.changes['checksum'] = newconfig.get("General", "checksum")
-          newconfig.set("General", "checksum", "XXXXXXXXXX")
-          with open("/tmp/mythbuntu-bare.tmp", 'w') as conffile:
-            newconfig.write(conffile)
-          h = hashlib.sha1()
-          f = open("/tmp/mythbuntu-bare.tmp", "rb")
-          h.update(f.read())
-          hsh = h.hexdigest()
-          f.close()
-          if hsh == self.changes['checksum']:
-            try:
-              self.changes['serverip'] = newconfig.get("General", "serverip")
-              self.changes['serverport'] = newconfig.get("General", "serverport")
-              self.changes['managed'] = newconfig.get("General", "managed")
-              self.changes['BackupLocation'] = newconfig.get("Backup", "storagedir")
-              self.changes['backup_db'] = newconfig.get("Backup", "db")
-              self.changes['backup_schedule_day'] = newconfig.get("Backup", "day")
-              self.changes['backup_schedule_hour'] = newconfig.get("Backup", "hour")
-              self.changes['backup_schedule_minute'] = newconfig.get("Backup", "minute")
-              self.changes['backup_schedule_weekday'] = newconfig.get("Backup", "weekday")
-              self.changes['backup_schedule'] = newconfig.get("Backup", "schedule")
-              self.ValidNewConf = True
-              self.managed_label_isfile.hide()
-            except:
-              self.ValidNewConf = False
-              self.managed_label_isfile.show()
-          else:
-            print "Error: Signature failure. Configuration file possibly corrupt."
+            newconfigfilename=self.managedfilechooser.get_filename()
+            newconfig = ConfigParser.ConfigParser()
+            newconfig.read(newconfigfilename)
+            self.changes['checksum'] = newconfig.get("General", "checksum")
+            newconfig.set("General", "checksum", "XXXXXXXXXX")
+            with open("/tmp/mythbuntu-bare.tmp", 'w') as conffile:
+                newconfig.write(conffile)
+            h = hashlib.sha1()
+            f = open("/tmp/mythbuntu-bare.tmp", "rb")
+            h.update(f.read())
+            hsh = h.hexdigest()
+            f.close()
+            if hsh == self.changes['checksum']:
+                try:
+                    self.changes['serverip'] = newconfig.get("General", "serverip")
+                    self.changes['serverport'] = newconfig.get("General", "serverport")
+                    self.changes['managed'] = newconfig.get("General", "managed")
+                    self.changes['BackupLocation'] = newconfig.get("Backup", "storagedir")
+                    self.changes['backup_db'] = newconfig.get("Backup", "db")
+                    self.changes['backup_schedule_day'] = newconfig.get("Backup", "day")
+                    self.changes['backup_schedule_hour'] = newconfig.get("Backup", "hour")
+                    self.changes['backup_schedule_minute'] = newconfig.get("Backup", "minute")
+                    self.changes['backup_schedule_weekday'] = newconfig.get("Backup", "weekday")
+                    self.changes['backup_schedule'] = newconfig.get("Backup", "schedule")
+                    self.ValidNewConf = True
+                    self.managed_label_isfile.hide()
+                except:
+                    self.ValidNewConf = False
+                    self.managed_label_isfile.show()
+            else:
+                print "Error: Signature failure. Configuration file possibly corrupt."
 
     def on_button_started_clicked(self,widget,data=None):
         self.tab_history=[]
@@ -274,12 +277,12 @@ class MythbuntuBaRePlugin(MCCPlugin):
     def on_back_button_clicked(self,widget,data=None):
         self.hide_tabs()
         if self.CUR_TAB == "vbox_final":
-          self.next_button.set_sensitive(True)
+            self.next_button.set_sensitive(True)
         self.CUR_TAB = self.tab_history.pop()
         f = getattr(self, self.CUR_TAB)
         f.show()
         if self.CUR_TAB == "vbox_start":
-          self.button_box.hide()
+            self.button_box.hide()
 
     def change_tab(self,CURRENT,DIRECTION):
         """Monkee around to display the correct wizard page"""
@@ -328,20 +331,22 @@ class MythbuntuBaRePlugin(MCCPlugin):
             self.vbox_final.show()
             self.next_button.set_sensitive(False)
         elif self.CUR_TAB == "vbox_backup_location":
-            self.tab_history.append(self.CUR_TAB)
-            self.CUR_TAB = "vbox_final"
-            self.vbox_final.show()
-            self.next_button.set_sensitive(False)
+            #from u1files import U1Files
+            if self.backup_dir_button.get_active():# or (self.BACKUP_LOCATION == "U1" and U1Files().login()):
+                self.tab_history.append(self.CUR_TAB)
+                self.CUR_TAB = "vbox_final"
+                self.vbox_final.show()
+                self.next_button.set_sensitive(False)
         elif self.CUR_TAB == "vbox_set_schedule":
             if self.schedule_daily_button.get_active() or (self.schedule_monthly_button.get_active() and not self.monthly_combobox.get_active_text() == None) or (self.schedule_weekly_button.get_active() and not self.weekly_combobox.get_active_text() == None):
-              self.tab_history.append(self.CUR_TAB)
-              self.CUR_TAB = "vbox_backup_location"
-              self.vbox_backup_location.show()
+                self.tab_history.append(self.CUR_TAB)
+                self.CUR_TAB = "vbox_backup_location"
+                self.vbox_backup_location.show()
             elif self.schedule_disabled_button.get_active():
-              self.tab_history.append(self.CUR_TAB)
-              self.CUR_TAB = "vbox_final"
-              self.vbox_final.show()
-              self.next_button.set_sensitive(False)
+                self.tab_history.append(self.CUR_TAB)
+                self.CUR_TAB = "vbox_final"
+                self.vbox_final.show()
+                self.next_button.set_sensitive(False)
         elif self.CUR_TAB == "vbox_managed_convert":
             if self.ValidNewConf == True:
                 self.tab_history.append(self.CUR_TAB)
@@ -367,32 +372,32 @@ class MythbuntuBaRePlugin(MCCPlugin):
         texthour = self.schedule_hour_combobox.get_active_text()
         textminute = self.schedule_minute_combobox.get_active_text()
         if self.schedule_weekly_button.get_active():
-          self.schedule_label_sent.show()
-          self.hbox_schedule.show()
-          self.hbox_schedule_weekly.show()
-          self.schedule_label_sent.set_text("Scheduled backup will be set to run weekly on "+str(self.weekly_combobox.get_active_text())+" at "+texthour+":"+textminute)
+            self.schedule_label_sent.show()
+            self.hbox_schedule.show()
+            self.hbox_schedule_weekly.show()
+            self.schedule_label_sent.set_text("Scheduled backup will be set to run weekly on "+str(self.weekly_combobox.get_active_text())+" at "+texthour+":"+textminute)
         elif self.schedule_monthly_button.get_active():
-          self.schedule_label_sent.show()
-          self.monthly_text_label.show()
-          self.monthly_the_label.show()
-          self.hbox_schedule.show()
-          self.hbox_schedule_monthly.show()
-          self.schedule_label_sent.set_text("Scheduled backup will be set to run monthly on the "+str(self.monthly_combobox.get_active_text())+" day at "+texthour+":"+textminute)
+            self.schedule_label_sent.show()
+            self.monthly_text_label.show()
+            self.monthly_the_label.show()
+            self.hbox_schedule.show()
+            self.hbox_schedule_monthly.show()
+            self.schedule_label_sent.set_text("Scheduled backup will be set to run monthly on the "+str(self.monthly_combobox.get_active_text())+" day at "+texthour+":"+textminute)
         elif self.schedule_daily_button.get_active():
-          self.schedule_label_sent.show()
-          self.schedule_label_sent.set_text("Scheduled backup will be set to run daily at "+texthour+":"+textminute)
+            self.schedule_label_sent.show()
+            self.schedule_label_sent.set_text("Scheduled backup will be set to run daily at "+texthour+":"+textminute)
         self.set_final_label()
 
     def set_final_label(self):
         if self.radio_convert.get_active():
-          self.job_label.set_text("Please click apply to convert the machine to managed mode")
+            self.job_label.set_text("Please click apply to convert the machine to managed mode")
         if self.radio_restore.get_active():
-          self.job_label.set_text("Please click apply to perform the restore procedure")
+            self.job_label.set_text("Please click apply to perform the restore procedure")
         if self.radio_backup.get_active():
-          if self.backup_schedule.get_active():
-            self.job_label.set_text("Please click apply to perform the specified scheduling changes")
-          else:
-            self.job_label.set_text("Please click apply to perform the backup procedure")
+            if self.backup_schedule.get_active():
+                self.job_label.set_text("Please click apply to perform the specified scheduling changes")
+            else:
+                self.job_label.set_text("Please click apply to perform the backup procedure")
 
     def on_backup_dir_button_toggled(self,widget,data=None):
         """Prompt user for save location if needed"""
@@ -401,8 +406,10 @@ class MythbuntuBaRePlugin(MCCPlugin):
             self.backup_location.show()
         elif self.backup_u1_button.get_active():
             self.preconfigured_label.show()
+            self.BACKUP_LOCATION = "U1"
         elif self.backup_dropbox_button.get_active():
             self.preconfigured_label.show()
+            self.BACKUP_LOCATION = "DROPBOX"
         else:        
             print "Error: Unknown option selected"
 
@@ -453,13 +460,15 @@ class MythbuntuBaRePlugin(MCCPlugin):
             if item == "Save Backup Location":
                 self.BACKUP_LOCATION = reconfigure[item]
         for item in reconfigure:
-            if item == "Backup Schedule":
+            if item == "BackupSchedule":
+                self.emit_progress("Processing Backup Schedule", 10)
                 if reconfigure[item] == False:
                     self.emit_progress("Removing scheduled job", 50)
                     if os.path.isfile("/etc/cron.d/mythbuntu-bare"):
                         os.remove("/etc/cron.d/mythbuntu-bare")
                 elif reconfigure[item] == True:
                     CONFIGFILE = "/var/lib/mythtv/bare-client/mythbuntu-bare-client.conf"
+                    self.emit_progress("Saving Backup Settings", 30)
                     import ConfigParser
                     config = ConfigParser.ConfigParser()
                     config.add_section('General')
@@ -468,23 +477,23 @@ class MythbuntuBaRePlugin(MCCPlugin):
                     config.set('General', 'managed', 'false')
                     config.set('General', 'revision', '1')
                     for subitem in reconfigure:
-                        if subitem == 'Backup Hour':
+                        if subitem == 'BackupHour':
                             config.set('Backup', 'hour', reconfigure[subitem])
-                        elif subitem == 'Backup Minute':
+                        elif subitem == 'BackupMinute':
                             config.set('Backup', 'minute', reconfigure[subitem])
-                        elif subitem == 'Backup Location':
+                        elif subitem == 'BackupLocation':
                             config.set('Backup', 'storagedir', reconfigure[subitem])
-                        elif subitem == 'Backup Database':
+                        elif subitem == 'BackupDatabase':
                             config.set('Backup', 'db', reconfigure[subitem])
-                        elif subitem == 'Backup Daily':
+                        elif subitem == 'BackupDaily':
                             config.set('Backup', 'schedule', 'daily')
                             config.set('Backup', 'day', '*')
                             config.set('Backup', 'weekday', '*')
-                        elif subitem == 'Backup Weekly':
+                        elif subitem == 'BackupWeekly':
                             config.set('Backup', 'schedule', 'weekly')
                             config.set('Backup', 'day', '*')
                             config.set('Backup', 'weekday', reconfigure[subitem])
-                        elif subitem == 'Backup Monthly':
+                        elif subitem == 'BackupMonthly':
                             config.set('Backup', 'schedule', 'monthly')
                             config.set('Backup', 'day', reconfigure[subitem])
                             config.set('Backup', 'weekday', '*')
@@ -492,6 +501,7 @@ class MythbuntuBaRePlugin(MCCPlugin):
                         config.write(conffile)
                     sys.path.append("/usr/share/mythbuntu/bare")
                     from updater import CronUpdater
+                    self.emit_progress("Saving Backup Schedule", 10)
                     CronUpdater().generate_cron_schedule()
             elif item == "restore":
                 RESTORE_LOCATION=reconfigure[item]
@@ -533,7 +543,6 @@ class MythbuntuBaRePlugin(MCCPlugin):
             self.emit_progress("Restore Job Complete", 100)
         time.sleep(2)
 
-
     def user_scripted_changes(self,reconfigure):
         """Local changes that can be performed by the user account.
            This function will be ran by the frontend"""
